@@ -87,6 +87,8 @@ FCITX_CONFIGURATION(
                                 _("Backward phrase choice"), true};
     Option<bool> AutoShiftCursor{this, "AutoShiftCursor",
                                  _("Automatically shift cursor"), false};
+    Option<bool> EasySymbolInput{this, "EasySymbolInput",
+                                 _("Enable easy symbol"), false};
     Option<bool> SpaceAsSelection{this, "SpaceAsSelection",
                                   _("Space as selection key"), true};
     OptionWithAnnotation<ChewingLayout, ChewingLayoutI18NAnnotation> Layout{
@@ -112,6 +114,7 @@ public:
     const Configuration *getConfig() const override { return &config_; }
     void setConfig(const RawConfig &config) override {
         config_.load(config, true);
+        populateConfig();
         safeSaveAsIni(config_, "conf/chewing.conf");
     }
 
